from pylab import *

#on recupere les valeurs a z=0.5
#simlss data
k,pk,pkno=loadtxt("simlss_dr9_z0.5.txt",skiprows=2,unpack=True,usecols=(0,1,2))

#d'apres HE
h=0.7
Om0=0.27
Ob0=0.05
s=44.5*log(9.83/(Om0*h**2))/sqrt(1+10*(Ob0*h**2)**(3./4))
print("H&E: s={}".format(s))

#repduction DR9
V=2200.**3
dk=0.004*h
kcut=(0.02*h,0.3*h)

N=(kcut[1]-kcut[0])/dk
kb=linspace(kcut[0],kcut[1],N)

#valeurs vraies interpolee
from scipy.interpolate import interp1d
f = interp1d(k, pk)
pkb=f(kb)

#(log10(kb/h),log10(pkb*h**3),'o-',markersize=3)

#erreurs
sig_pkb=2*pi/(sqrt(V*dk)*kb)*pkb
sig_pkb_log=sig_pkb/(2.3*pkb)


#plot Pk
figure()
errorbar(log10(kb/h),log10(pkb*h**3),yerr=sig_pkb_log,fmt='ko-',markersize=3)

###

#wiggles
g = interp1d(k, pkno)
pknob=g(kb)

pkwig=pkb/pknob
sig_wig=sig_pkb/pknob


figure()
errorbar(kb/h,log10(pkwig),yerr=sig_pkb_log,fmt='ko-',markersize=3)
xlabel("k (h/Mpc)")
ylabel("log10(pk/pksmooth)")
xlim(kcut)

#fit
from scipy import optimize
def fitfunc(k,A,ka):
    return 1+A*sqrt(k)*exp(-(k/0.1)**1.4)*sin(2*pi*k/ka)

p0=[1,2*pi/s]
p, pcov=optimize.curve_fit(fitfunc,kb,pkwig,sigma=sig_wig,p0=p0,absolute_sigma=True)
plot(k/h,log10(fitfunc(k,p[0],p[1])),'b',label="Fit",ls='dashed')

print("s_rec={}".format(2*pi/p[1]))

##
#loop

ntry=1000
hs=zeros(ntry)
for i in range(ntry):
    n=randn(len(kb))
    pk_i=pkb+n*sig_pkb
    y=pk_i/pknob
    p, pcov=optimize.curve_fit(fitfunc,kb,y,p0=p0,sigma=sig_wig)
    print("s_rec={}".format(2*pi/p[1]))
    hs[i]=2*pi/p[1]
    if i<1:
        figure()
        #errorbar(kb,y,yerr=sig_wig,fmt='ko-',markersize=3)
        #plot(kb,fitfunc(kb,p[0],p[1]),'b',label="Fit",ls='dashed')
        errorbar(kb/h,log10(y),yerr=sig_pkb_log,fmt='ko',markersize=5)
        plot(k/h,log10(fitfunc(k,p[0],p[1])),'k',label="Fit")
        ylim(-0.05,0.05)
        xlim(kcut)


#clf()

figure()
hist(hs)
from scipy import stats
t=stats.describe(hs)

stat=[r"$N={:d}$".format(t[0]),r"$\mu={:f}$".format(t[2]),r"$\sigma={:f}$".format(sqrt(t[3]))]
figtext(0.7,0.75,"\n".join(stat))

print("sig(s)={}".format(hs.std()))
 


show()

